@@ -15,14 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-shell.h,v 1.17 2005/07/04 12:22:40 chpe Exp $
+ *  $Id: ephy-embed-shell.h,v 1.21 2006/06/18 18:30:23 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_SHELL_H
 #define EPHY_EMBED_SHELL_H
 
-#include <glib-object.h>
 #include <glib.h>
+#include <glib-object.h>
+#include <gtk/gtkpagesetup.h>
+#include <gtk/gtkprintsettings.h>
 
 G_BEGIN_DECLS
 
@@ -59,18 +61,34 @@ struct _EphyEmbedShellClass
 
 GType		   ephy_embed_shell_get_type		(void);
 
+EphyEmbedShell	  *ephy_embed_shell_get_default		(void);
+
 GObject		  *ephy_embed_shell_get_favicon_cache	(EphyEmbedShell *ges);
 
 GObject		  *ephy_embed_shell_get_global_history	(EphyEmbedShell *shell);
 
 GObject		  *ephy_embed_shell_get_downloader_view	(EphyEmbedShell *shell);
 
+GObject		  *ephy_embed_shell_get_downloader_view_nocreate	(EphyEmbedShell *shell);
+
 GObject		  *ephy_embed_shell_get_encodings	(EphyEmbedShell *shell);
 
 GObject		  *ephy_embed_shell_get_embed_single	(EphyEmbedShell *shell);
 
+GObject        	  *ephy_embed_shell_get_adblock_manager	(EphyEmbedShell *shell);
+
 void		   ephy_embed_shell_prepare_close	(EphyEmbedShell *shell);
 
+void		   ephy_embed_shell_set_page_setup	(EphyEmbedShell *shell,
+							 GtkPageSetup *page_setup);
+		
+GtkPageSetup	  *ephy_embed_shell_get_page_setup	(EphyEmbedShell *shell);
+
+void		   ephy_embed_shell_set_print_settings	(EphyEmbedShell *shell,
+							 GtkPrintSettings *settings);
+		
+GtkPrintSettings  *ephy_embed_shell_get_print_settings	(EphyEmbedShell *shell);
+
 G_END_DECLS
 
 #endif /* !EPHY_EMBED_SHELL_H */
