@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.c,v 1.90 2006/02/24 13:27:22 paharvey Exp $
+ *  $Id: egg-editable-toolbar.c,v 1.92 2006/05/30 09:04:39 fpeters Exp $
  */
 
 #include "config.h"
@@ -532,6 +532,9 @@ action_sensitive_cb (GtkAction   *action,
   EggEditableToolbar *etoolbar = EGG_EDITABLE_TOOLBAR
     (gtk_widget_get_ancestor (GTK_WIDGET (item), EGG_TYPE_EDITABLE_TOOLBAR));
 
+  if (etoolbar == NULL)
+    return;
+
   if (etoolbar->priv->edit_mode > 0)
     {
       gtk_widget_set_sensitive (GTK_WIDGET (item), TRUE);
@@ -1685,8 +1688,7 @@ egg_editable_toolbar_set_fixed (EggEditableToolbar *etoolbar,
     {
       priv->fixed_toolbar = GTK_WIDGET (toolbar);
       gtk_toolbar_set_show_arrow (toolbar, FALSE);
-      g_object_ref (toolbar);
-      gtk_object_sink (GTK_OBJECT (toolbar));
+      g_object_ref_sink (toolbar);
     }
 
   update_fixed (etoolbar);
