@@ -16,11 +16,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.142 2006/03/02 21:23:34 jframeau Exp $
+ *  $Id: ephy-shell.c,v 1.144 2006/06/18 18:30:24 chpe Exp $
  */
 
 #include "config.h"
 
+#include <string.h>
+#include <glib/gi18n.h>
+#include <gtk/gtknotebook.h>
+#include <dirent.h>
+#include <unistd.h>
+
 #include "ephy-shell.h"
 #include "ephy-type-builtins.h"
 #include "ephy-embed-shell.h"
@@ -44,16 +50,9 @@
 #include "egg-toolbars-model.h"
 #include "ephy-toolbars-model.h"
 #include "ephy-toolbar.h"
-#include "print-dialog.h"
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
 
-#include <string.h>
-#include <glib/gi18n.h>
-#include <gtk/gtknotebook.h>
-#include <dirent.h>
-#include <unistd.h>
-
 #ifdef ENABLE_NETWORK_MANAGER
 #include "ephy-net-monitor.h"
 #endif
@@ -75,7 +74,6 @@ struct _EphyShellPrivate
 	GtkWidget *history_window;
 	GObject *pdm_dialog;
 	GObject *prefs_dialog;
-	GObject *print_setup_dialog;
 	GList *del_on_exit;
 
 	guint embed_single_connected : 1;
@@ -354,13 +352,6 @@ ephy_shell_dispose (GObject *object)
 		priv->prefs_dialog = NULL;
 	}
 
-	if (priv->print_setup_dialog != NULL)
-	{
-		LOG ("Unref print setup dialog");
-		g_object_unref (priv->print_setup_dialog);
-		priv->print_setup_dialog = NULL;
-	}
-
 	if (priv->bookmarks != NULL)
 	{
 		LOG ("Unref bookmarks");
@@ -565,6 +556,15 @@ ephy_shell_new_tab_full (EphyShell *shell,
                 }
         }
 
+	if (previous_embed != NULL)
+	{
+		ephy_embed_shistory_copy (previous_embed,
+					  embed,
+					  TRUE,   /* back history */
+					  FALSE,  /* forward history */
+					  FALSE); /* current index */
+	}
+
 	return tab;
 }
 
@@ -846,24 +846,6 @@ ephy_shell_get_prefs_dialog (EphyShell *shell)
 	return shell->priv->prefs_dialog;
 }
 
-GObject *
-ephy_shell_get_print_setup_dialog (EphyShell *shell)
-{
-	if (shell->priv->print_setup_dialog == NULL)
-	{
-		GObject **dialog;
-
-		shell->priv->print_setup_dialog = G_OBJECT (ephy_print_setup_dialog_new ());
-
-		dialog = &shell->priv->print_setup_dialog;
-
-		g_object_add_weak_pointer (shell->priv->print_setup_dialog,
-					   (gpointer *) dialog);
-	}
-
-	return shell->priv->print_setup_dialog;
-}
-
 void
 _ephy_shell_create_instance (void)
 {
