@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright (C) 2003, 2004, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.h,v 1.35 2005/04/17 19:39:00 chpe Exp $
+ *  $Id: ephy-shell.h,v 1.38 2006/06/18 18:30:24 chpe Exp $
  */
 
 #ifndef EPHY_SHELL_H
@@ -45,26 +45,6 @@ typedef struct _EphyShellPrivate	EphyShellPrivate;
 
 extern EphyShell *ephy_shell;
 
-#define EPHY_SHELL_ERROR ephy_shell_error_quark ()
-
-typedef enum
-{
-	EPHY_SHELL_ERROR_MISSING_SERVER,
-	EPHY_SHELL_ERROR_OBJECT_REG_FAILED,
-	EPHY_SHELL_ERROR_FACTORY_REG_FAILED
-} EphyShellError;
-
-typedef enum
-{
-	EPHY_SHELL_STARTUP_TABS			= 1 << 0,
-	EPHY_SHELL_STARTUP_EXISTING_WINDOW	= 1 << 2,
-	EPHY_SHELL_STARTUP_FULLSCREEN		= 1 << 3,
-	EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR	= 1 << 4,
-	EPHY_SHELL_STARTUP_SESSION		= 1 << 5,
-	EPHY_SHELL_STARTUP_IMPORT_BOOKMARKS	= 1 << 6,
-	EPHY_SHELL_STARTUP_ADD_BOOKMARK		= 1 << 7
-} EphyShellStartupFlags;
-
 typedef enum
 {
 	/* Page types */
@@ -97,27 +77,12 @@ struct _EphyShellClass
 	EphyEmbedShellClass parent_class;
 };
 
-GType		ephy_shell_error_get_type		(void) G_GNUC_CONST;
-
-GType		ephy_shell_startup_flags_get_type	(void) G_GNUC_CONST;
-
 GType		ephy_new_tab_flags_get_type		(void) G_GNUC_CONST;
 
 GType		ephy_shell_get_type			(void);
 
-GQuark		ephy_shell_error_quark			(void);
-
 EphyShell      *ephy_shell_get_default			(void);
 
-EphyShell      *ephy_shell_new				(void);
-
-gboolean	ephy_shell_startup			(EphyShell *shell,
-							 EphyShellStartupFlags flags,
-							 guint32 user_time,
-							 const char **args,
-							 const char *string_arg,
-							 GError **error);
-
 EphyTab	       *ephy_shell_new_tab			(EphyShell *shell,
 							 EphyWindow *parent_window,
 							 EphyTab *previous_tab,
@@ -135,6 +100,8 @@ EphyTab	       *ephy_shell_new_tab_full			(EphyShell *shell,
 
 GObject	       *ephy_shell_get_session			(EphyShell *shell);
 
+GObject	       *ephy_shell_get_net_monitor		(EphyShell *shell);
+
 EphyBookmarks  *ephy_shell_get_bookmarks		(EphyShell *shell);
 
 GObject	       *ephy_shell_get_toolbars_model		(EphyShell *shell,
@@ -150,9 +117,8 @@ GObject        *ephy_shell_get_pdm_dialog		(EphyShell *shell);
 
 GObject        *ephy_shell_get_prefs_dialog		(EphyShell *shell);
 
-GObject	       *ephy_shell_get_print_setup_dialog	(EphyShell *shell);
-
-GObject	       *ephy_shell_get_dbus_service		(EphyShell *shell);
+/* private API */
+void	       _ephy_shell_create_instance		(void);
 
 G_END_DECLS
 
