@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.193 2006/04/24 07:45:19 chpe Exp $
+ *  $Id: window-commands.c,v 1.195 2006/07/06 20:53:54 chpe Exp $
  */
 
 #include "config.h"
@@ -59,17 +59,32 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtktoggleaction.h>
+#include <gtk/gtkprintoperation.h>
 #include <glib/gi18n.h>
 
+static void
+page_setup_done_cb (GtkPageSetup *setup,
+		    EphyEmbedShell *shell)
+{
+	if (setup != NULL)
+	{
+		ephy_embed_shell_set_page_setup (shell, setup);
+	}
+}
+
 void
 window_cmd_file_print_setup (GtkAction *action,
 			     EphyWindow *window)
 {
-	EphyDialog *dialog;
+	EphyEmbedShell *shell;
 
-	dialog = EPHY_DIALOG (ephy_shell_get_print_setup_dialog (ephy_shell));
-
-	ephy_dialog_show (dialog);
+	shell = ephy_embed_shell_get_default ();
+	gtk_print_run_page_setup_dialog_async
+		(GTK_WINDOW (window),
+		 ephy_embed_shell_get_page_setup (shell),
+		 ephy_embed_shell_get_print_settings (shell),
+		 (GtkPageSetupDoneFunc) page_setup_done_cb,
+		 shell);
 }
 
 void
